function RegisterToOpcuaUpdatePage()
{
	var IsSaveGlobalVariable = function(){return RegisterToOpcuaUpdatePage.prototype._IsSaveRegisterGlobalVariable_();};
	var IsSaveRegisterMasterModuleGlobalVariable = function(){return RegisterToOpcuaUpdatePage.prototype.IsSaveRegisterMasterModuleGlobalVariable();};
	var ShowFirstPage = function(){RegisterToOpcuaUpdatePage.prototype._ShowFirstPage_();};
	var SaveGlobalVariable = function(Row){RegisterToOpcuaUpdatePage.prototype._SaveGlobalVariable_(Row);};
	this.Initialization = function(){RegisterToOpcuaUpdatePage.prototype._Initialization_();};

}
function RegisterToOpcuaFirstPage()
{
	this.RedisplayUi = function(){RegisterToOpcuaFirstPage.prototype._RedisplayUi_();};
	//取值
	var GetAllDeviceName = function(){return RegisterToOpcuaFirstPage.prototype._GetAllDeviceName_();};
	var GetAllNumber     = function(){return RegisterToOpcuaFirstPage.prototype._GetAllNumber_();};
	var GetAllModuleData = function(){return RegisterToOpcuaFirstPage.prototype._GetAllModuleData_();};

	//工具列
	var UpdateTableToolbar = function(ObjectKey, DisplayNumber){RegisterToOpcuaFirstPage.prototype._UpdateTableToolbar_(ObjectKey, DisplayNumber);};
	this.ShowPreviousPage  = function(){RegisterToOpcuaFirstPage.prototype._ShowPreviousPage_();};
	this.ShowNextPage      = function(){RegisterToOpcuaFirstPage.prototype._ShowNextPage_();};
	//表格
	var ShowTable = function(ObjectKey, DisplayNumber){RegisterToOpcuaFirstPage.prototype._ShowTable_(ObjectKey, DisplayNumber);};
  	//判斷
  	var IsAllTransformOpcUa = function(){return RegisterToOpcuaFirstPage.prototype._IsAllTransformOpcUa_();};
	//Checkbox
  	this.ChangeAllCheckbox = function(that){RegisterToOpcuaFirstPage.prototype._ChangeAllCheckbox_(that);};
  	this.ChangeCheckbox    = function(that){RegisterToOpcuaFirstPage.prototype._ChangeCheckbox_(that);};
	//按鈕
	this.EditButton = function(that){RegisterToOpcuaFirstPage.prototype._EditButton_(that);};
	this.SaveButton = function(that){RegisterToOpcuaFirstPage.prototype._SaveButton_(that);};
	//初始化
	//this.Initialization = function(){MqttToOpcuaFirstPage.prototype._Initialization_();};
	//傳輸
	var TransmissionJson = function(ssocket, Command, JsonString, Callback){RegisterToOpcuaFirstPage.prototype._TransmissionJson_(ssocket, Command, JsonString, Callback);};
	var SaveFinished     = function(that, ssocket){RegisterToOpcuaFirstPage.prototype._SaveFinished_(that, ssocket);};
	var SaveStart        = function(that, ssocket){RegisterToOpcuaFirstPage.prototype._SaveStart_(that, ssocket);};
}
function RegisterToOpcuaSecondPage()
{
	//全域變數 或 物件
	//var ModifyMqttToOpcuaVariableObject = function(that){MqttToOpcuaSecondPage.prototype._ModifyMqttToOpcuaVariableObject_(that);};
	var SetFormInitialValue             = function(number){RegisterToOpcuaSecondPage.prototype._SetFormInitialValue_(number);};
	var SetInitialValue                 = function(number){RegisterToOpcuaSecondPage.prototype._SetInitialValue_(number);};
	//介面
	var ClearTable       = function(number){RegisterToOpcuaSecondPage.prototype._ClearTable_(number);};
	this.ConfirmButton   = function(){RegisterToOpcuaSecondPage.prototype._ConfirmButton_();};
	this.NoConfirmButton = function(){RegisterToOpcuaSecondPage.prototype._NoConfirmButton_();};
	//變數表
	var VariableTableAddNewRow       = function(number){RegisterToOpcuaSecondPage.prototype._VariableTableAddNewRow_(number);};
	var SetVariableTableNewRowValue  = function(number){RegisterToOpcuaSecondPage.prototype._SetVariableTableNewRowValue_(number);};
	var SetVariableTableInitialValue = function(number){RegisterToOpcuaSecondPage.prototype._SetVariableTableInitialValue_(number);};  
	//取值
	var GetModuleName = function(number){return RegisterToOpcuaSecondPage.prototype._GetModuleName_(number);};
}




/*
function MqttToOpcuaUpdatePage()
{
	
	
	
}
function MqttToOpcuaFirstPage()
{

    //介面
  




  //交集，差集
  var ArrayInteraction = function(FirstArray, SecondArray){return MqttToOpcuaFirstPage.prototype._ArrayInteraction_(FirstArray, SecondArray);};
  var ArrayComplement  = function(FirstArray, SecondArray){return MqttToOpcuaFirstPage.prototype._ArrayComplement_(FirstArray, SecondArray);};
    
}










function MqttToOpcuaSecondPage()
{

  //交集 差集
  var ArrayInteraction = function(FirstArray, SecondArray){return MqttToOpcuaSecondPage.prototype._ArrayInteraction_(FirstArray, SecondArray);};
  var ArrayComplement  = function(FirstArray, SecondArray){return MqttToOpcuaSecondPage.prototype._ArrayComplement_(FirstArray, SecondArray);};

    //對照
  var GetReadWriteType = function(string){return MqttToOpcuaSecondPage.prototype._GetReadWriteType_(string);};
}*/