//-----------Left List-----------
function main_RegisterToOpcua_click(that)
{
	var LeftDivId="#Main_Left-List";
	var Class = new ListCommon();
	Class.ChangeDivCss(that, LeftDivId);
	Class = new Path();
	Class.LoadPathHtml($(that).text(), 1, "main_PathRegisterModule_click(this)");
	Class = new LoadHtml();
	var Html = Class.GetVariableTranslationHtml(Global_RegisterToOpcuaCss);
	Html = Html + Class.GetVariableTranslationHtml(Global_RegisterToOpcuaUpdatePageHtml);
	Html = Html + Class.GetVariableTranslationHtml(Global_RegisterToOpcuaFirstPageHtml);
	Html = Html + Class.GetVariableTranslationHtml(Global_RegisterToOpcuaSecondPageHtml);
	$("#Main_Center-Content").empty();
	$("#Main_Center-Content").append(Html);
	Class = new RegisterToOpcuaUpdatePage();
	Class.Initialization();
	Class = null;
}
//-----------Center-----------
//__________Register / OPC UA 轉換傳輸__________
  //第一頁

function main_RegisterToOpcuaChangeCheckbox_click(that)
{
	var Class = new RegisterToOpcuaFirstPage();
	Class.ChangeCheckbox(that);
	Class = null;
}
function main_RegisterToOpcuaSettingButton_click(that)
{
	var Class = new RegisterToOpcuaFirstPage();
	Class.EditButton(that);
	Class = null;
}
function main_RegisterToOpcuaChangeAllCheckbox_click(that)
{
	var Class = new RegisterToOpcuaFirstPage();
	Class.ChangeAllCheckbox(that);
	Class = null;
}
function main_RegisterToOpcuaShowPreviousPage_click()
{
	var Class = new RegisterToOpcuaFirstPage();
	Class.ShowPreviousPage();
	Class = null;
}
function main_RegisterToOpcuaShowNextPage_click()
{
	var Class = new RegisterToOpcuaFirstPage();
	Class.ShowNextPage();
	Class = null;
}
function main_RegisterToOpcuaSaveButton_click(that)
{
	var Class = new RegisterToOpcuaFirstPage();
	Class.SaveButton(that);
	Class = null;
}











// 第二頁
function main_RegisterToOpcuaConfirmButton_click()
{
	var Class = new RegisterToOpcuaSecondPage();
	Class.ConfirmButton();
	Class = null;
}
function main_RegisterToOpcuaNoConfirmButton_click()
{
	var Class = new RegisterToOpcuaSecondPage();
	Class.NoConfirmButton();
	Class = null;
}










































//-----------Top Path-----------
  //路徑鈕 註冊的function
function main_PathMqttToOpcua_click(that)
{
	var Class = new Path();
	Class.ClearTheDivOfTheTail(that, "#Main_Top-Path");
	$("#Main_Left-List").css("display", "block");
	Class = new MqttToOpcuaSecondPage();
	Class.NoConfirmButton();
	Class = null;
}








  //第二頁

